# cPyparsing

[Cython](http://cython.org/) implementation of [PyParsing](https://github.com/pyparsing/pyparsing) created for use in [Coconut](http://coconut-lang.org/) and [Undebt](https://github.com/Yelp/undebt).

Just `pip install cpyparsing` then `import cPyparsing as pyparsing` or otherwise use `cPyparsing` however you would normally use `pyparsing`.

`cPyparsing` is currently only up-to-date with `pyparsing==2.4.7`—`cPyparsing` has no current plans to support any `pyparsing>=3` features.

`cPyparsing` supports Python `2.6+` on Python 2 and Python `3.3+` on Python 3.
